==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/NegativeVolumeIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { NegativeVolumeIndexIndicatorDescription } from "./NegativeVolumeIndexIndicatorDescription";
/**
 * @hidden
 */
export let NegativeVolumeIndexIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class NegativeVolumeIndexIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (NegativeVolumeIndexIndicatorDescriptionMetadata.a == null) {
                NegativeVolumeIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                NegativeVolumeIndexIndicatorDescriptionMetadata.c(NegativeVolumeIndexIndicatorDescriptionMetadata.a);
            }
            if (a.k(NegativeVolumeIndexIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(NegativeVolumeIndexIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            NegativeVolumeIndexIndicatorDescriptionMetadata.b(a);
            a.ad("NegativeVolumeIndexIndicator", () => new NegativeVolumeIndexIndicatorDescription());
            a.ac("NegativeVolumeIndexIndicator", NegativeVolumeIndexIndicatorDescriptionMetadata.a);
        }
    }
    NegativeVolumeIndexIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(NegativeVolumeIndexIndicatorDescriptionMetadata, 'NegativeVolumeIndexIndicatorDescriptionMetadata');
    NegativeVolumeIndexIndicatorDescriptionMetadata.a = null;
    return NegativeVolumeIndexIndicatorDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/NegativeVolumeIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { NegativeVolumeIndexIndicatorDescription } from "./NegativeVolumeIndexIndicatorDescription";
/**
 * @hidden
 */
export let NegativeVolumeIndexIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class NegativeVolumeIndexIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (NegativeVolumeIndexIndicatorDescriptionMetadata.a == null) {
                NegativeVolumeIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                NegativeVolumeIndexIndicatorDescriptionMetadata.c(NegativeVolumeIndexIndicatorDescriptionMetadata.a);
            }
            if (a.k(NegativeVolumeIndexIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(NegativeVolumeIndexIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            NegativeVolumeIndexIndicatorDescriptionMetadata.b(a);
            a.ae("NegativeVolumeIndexIndicator", () => new NegativeVolumeIndexIndicatorDescription());
            a.ad("NegativeVolumeIndexIndicator", NegativeVolumeIndexIndicatorDescriptionMetadata.a);
        }
    }
    NegativeVolumeIndexIndicatorDescriptionMetadata.$t = /*@__PURE__*/ markType(NegativeVolumeIndexIndicatorDescriptionMetadata, 'NegativeVolumeIndexIndicatorDescriptionMetadata');
    NegativeVolumeIndexIndicatorDescriptionMetadata.a = null;
    return NegativeVolumeIndexIndicatorDescriptionMetadata;
})();
